sqltriples.Expression

Module sqltriples :: Class Expression |
[show private | hide private]
[frames | no frames]

## Class Expression

    AbstractExpression --+
                         |
                        Expression

Method Summary
| `__init__(self, expr, values, object_type)`
| `__getitem__(self, i)`
| `__len__(self)`
| `__str__(self)`

Generated by Epydoc 2.1 on Fri Mar 31 17:48:37 2006 | http://epydoc.sf.net